@@ -24,7 +24,7 @@ require Exporter;
         trig      => [ qw/sind cosd tand asind acosd atand atan2d equal/ ],
         );
 
-$VERSION =  '0.93';
+$VERSION =  '0.94';
 $RADEG   = ( 180 / pi );
 $DEGRAD  = ( pi / 180 );
 my $INV360     = ( 1.0 / 360.0 );
@@ -393,9 +393,7 @@ sub equal {
     my ($A, $B, $dp) = @_;
 
     return sprintf("%.${dp}g", $A) eq sprintf("%.${dp}g", $B);
-  }
-
-
+}
 
 #
 #
@@ -483,6 +481,18 @@ sub sun_rise_sun_set {
   else {
     @arg{ qw/lon lat alt offset/ } = @_;
   }
+
+  # This trick aims to fulfill two antagonistic purposes:
+  # -- do not load DateTime if the only function called is "sunrise"
+  # -- load DateTime implicitly if the user calls "sun_rise" or "sun_set". This is to be backward
+  # compatible with 0.92 or earlier, when Astro::Sunrise would load DateTime and thus, allow
+  # the user to remove this line from his script.
+  unless ($INC{DateTime}) {
+    eval "use DateTime";
+    carp $@
+      if $@;
+  }
+
   my ($longitude, $latitude) = @arg{ qw/lon lat/ };
   my $alt       = defined($arg{alt}    ) ?     $arg{alt}     : -0.833;
   my $offset    = defined($arg{offset} ) ? int($arg{offset}) : 0 ;
@@ -538,9 +548,9 @@ Astro::Sunrise - Perl extension for computing the sunrise/sunset on a given day
 
   # When will the sun rise on YAPC::Europe 2015?
   use Astro::Sunrise;
-  my ($sunrise, $sunset = sunrise(year => 2015, month => 9, day => 2, # YAPC::EU starts on 2nd September 2015
-                                  lon  => -3.6, lat   => 37.17        # Granada is 37°10'N, 3°36'W
-                                  tz   => 1,    dst   => 1);          # This is still summer, therefore DST
+  my ($sunrise, $sunset) = sunrise( { year => 2015, month => 9, day => 2, # YAPC::EU starts on 2nd September 2015
+                                      lon  => -3.6, lat   => 37.17,       # Granada is 37°10'N, 3°36'W
+                                      tz   => 1,    dst   => 1 } );       # This is still summer, therefore DST
 
   # When does the sun rise today in Salt Lake City (home to YAPC::NA 2015)?
   use Astro::Sunrise;
@@ -550,10 +560,10 @@ Astro::Sunrise - Perl extension for computing the sunrise/sunset on a given day
   # And when does it set tomorrow at Salt Lake City?
   use Astro::Sunrise;
   use DateTime;
-  $sunset_tomorrow = sun_set(lat => 40.75,   # 40°45'N,
-                             lon => -111.88, # 111°53'W
-                             alt => -0.833,  # standard value for the sun altitude at sunset
-                             offset => 1);   # day offset up to tomorrow
+  $sunset_tomorrow = sun_set( { lat => 40.75,    # 40°45'N,
+                                lon => -111.88,  # 111°53'W
+                                alt => -0.833,   # standard value for the sun altitude at sunset
+                                offset => 1 } ); # day offset up to tomorrow
 
 =head1 DESCRIPTION
 
@@ -625,8 +635,8 @@ Astronomical twilight (the sky is completely dark)
   ($sunrise, $sunset) = sunrise( { year    => $year,      month      => $month,     day => $day,
                                    lon     => $longitude, lat        => $latitude,
                                    tz      => $tz_offset, isdst      => $is_dst,
-                                   alt     => $altitude,  upper_limb => $upper_limb);
-                                   precise => $precise,   polar      => $action);
+                                   alt     => $altitude,  upper_limb => $upper_limb,
+                                   precise => $precise,   polar      => $action } );
 
   ($sunrise, $sunset) = sunrise(YYYY,MM,DD,longitude,latitude,Time Zone,DST);
 
@@ -663,7 +673,7 @@ They are given in decimal degrees. For example:
 
 Mandatory, can be positional (#4 and #5).
 
-=item TZ
+=item tz
 
 Time Zone is the offset from GMT
 
@@ -714,7 +724,7 @@ module emits no warning, but it returns either C<'day'> or C<'night'>.
 Example:
 
   # Loosely based on Alex Gough's activities: scientist and Perl programmer, who spent a year
-  # in Halley Base in 2006.
+  # in Halley Base in 2006. Let us suppose he arrived there on 15th January 2006.
   my ($sunrise, $sunset) = sunrise( { year => 2006, month => 1, day => 15,
                                       lon => -26.65, lat => -75.58, # Halley Base: 75°35'S 26°39'W
                                       tz  => 3, polar => 'retval' } );
@@ -744,7 +754,7 @@ what I have tried to accomplish with this.
 
 a) Compute sunrise or sunset as always, with one exception: to convert LHA from degrees to hours,
    divide by 15.04107 instead of 15.0 (this accounts for the difference between the solar day
-   and the sidereal day.
+   and the sidereal day).
 
 b) Re-do the computation but compute the Sun's RA and Decl, and also GMST0, for the moment
    of sunrise or sunset last computed.
@@ -828,10 +838,12 @@ receives two floating values and an integer value. It compares the floating numb
 and returns "1" if their most significant digits are equal. The integer value
 specifies how many digits are kept. E.g.
 
-  say equal(22/7, 355/113, 3) # prints 1, because :  22/7   = 3.14285715286
-                              #                     355/113 = 3.14159292035
-  say equal(22/7, 355/113, 4) # prints 0
+  say equal(22/7, 355/113, 3) # prints 1, because :  22/7   = 3.14285715286 rounded to 3.14
+                              #                     355/113 = 3.14159292035 rounded to 3.14
+  say equal(22/7, 355/113, 4) # prints 0, because :  22/7   = 3.14285715286 rounded to 3.143
+                              #                     355/113 = 3.14159292035 rounded to 3.142
 
+=back
 
 =head1 AUTHOR
 
@@ -843,18 +855,20 @@ Co-maintainer: Jean Forget (JFORGET at cpan dot org)
 =head1 SPECIAL THANKS
 
 Robert Creager [Astro-Sunrise@LogicalChaos.org]
-For providing help with converting Paul's C code to perl
-For providing code for sun_rise, sun_set sub's
+for providing help with converting Paul's C code to Perl,
+for providing code for sun_rise, sun_set subs.
 Also adding options for different altitudes.
 
 Joshua Hoblitt [jhoblitt@ifa.hawaii.edu]
-For providing the patch to convert to DateTime
+for providing the patch to convert to DateTime.
 
 Chris Phillips for providing patch for conversion to
 local time.
 
 Brian D Foy for providing patch for constants :)
 
+Gabor Szabo for pointing POD mistakes.
+
 =head1 CREDITS
 
 =over 4
@@ -865,15 +879,15 @@ for his excellent web page on the subject.
 
 =item Rich Bowen (rbowen@rbowen.com)
 
-for suggestions
+for suggestions.
 
 =item Adrian Blockley [adrian.blockley@environ.wa.gov.au]
 
-for finding a bug in the conversion to local time
+for finding a bug in the conversion to local time.
 
-=item Slaven Rezic
+=item Slaven Rezić
 
-for finding and fixing a bug with DST
+for finding and fixing a bug with DST.
 
 =back
 
